@@ -402,7 +402,8 @@ class Run():
             path_artifact = '/api/dataset-upload-token?subType=artifact'
             endpoint_get_token = self.remote_path.replace(
                 '/api/runs', path_artifact) + '&token=' + self.user_token
-            oss_config = requests.get(endpoint_get_token)
+            r = requests.get(endpoint_get_token)
+            oss_config = json.loads(r.text)
             AK = oss_config['accessKeyId']
             SK = oss_config['secretAccessKey']
             region = oss_config['region']
